### Eulerian Video Magnification
(running in the browser)

made with
Kevin Kwok and Guillermo Webster

## What is this?

In Fall 2014 (yeah... it's taken a really long time to post this), we took Bill Freeman and Antonio Torralba's class 6.869: Advances in Computer Vision. For our final project, we were supposed to implement some variation of one of the algorithms which were covered in class. We decided to implement Eulerian Video Magnification in the browser, to see if it could work with a live webcam feed.

If you wanna learn more about details of the algorithm, or check out the exciting sequels they've worked on. Check out the original 2012 paper or the 2013 phase-based technique.

## Wat? What's Video Magnification?

It's sort of like being Superman and having X-Ray vision. It's about being able to see things that wee ordinary people can't, because the changes are too small to notice. But rather than being like a microscope, which just blows everything up, it lets you appreciate subtle change at the original spatial scale.

## How does it work?

Like everything you've ever known and loved, Eulerian Video Magnification is built on a lie. It's a bit of an optical illusion because while it looks like things are moving more, the pixels aren't actually shifting around.

## Heading

Donec sed odio dui. Etiam porta sem malesuada magna mollis euismod. Nullam id dolor id nibh ultricies vehicula ut id elit. Morbi leo risus, porta ac consectetur ac, vestibulum at eros. Praesent commodo cursus magna.

View details »

## Heading

Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit. Cras mattis consectetur purus sit amet fermentum. Fusce dapibus, tellus ac cursus commodo, tortor mauris condimentum nibh.

View details »

## Heading

Donec sed odio dui. Cras justo odio, dapibus ac facilisis in, egestas eget quam. Vestibulum id ligula porta felis euismod semper. Fusce dapibus, tellus ac cursus commodo, tortor mauris condimentum nibh, ut fermentum massa justo sit amet risus.

View details »

## Oh yeah, it's that good. See for yourself.

Donec ullamcorper nulla non metus auctor fringilla. Vestibulum id ligula porta felis euismod semper. Praesent commodo cursus magna, vel scelerisque nisl consectetur. Fusce dapibus, tellus ac cursus commodo.

## And lastly, this one. Checkmate.

Donec ullamcorper nulla non metus auctor fringilla. Vestibulum id ligula porta felis euismod semper. Praesent commodo cursus magna, vel scelerisque nisl consectetur. Fusce dapibus, tellus ac cursus commodo.